@@ -7,5 +7,5 @@ setup(
     version="0.1.0",
     packages=find_namespace_packages(include=['namespace_package.*']),
     zip_safe=False,
-    rust_extensions=[RustExtension("namespace_package.bar", path="Cargo.toml", binding=Binding.PyO3, debug=False)],
+    rust_extensions=[RustExtension("namespace_package.rust", path="Cargo.toml", binding=Binding.PyO3, debug=False)],
 )
